@@ -5,24 +5,25 @@ osso_context_t *oss = NULL;
 
 TxtReader::TxtReader(QString infile)
 {
-        version = QString("0.6.8");
+        version = QString("0.6.9");
         setWindowTitle( QString("TXTReader %1").arg(version));
         qApp->installTranslator(&appTranslator);
-        oss = osso_initialize("txtreader", "0.6.7", FALSE, NULL);
+        oss = osso_initialize("txtreader", "0.6.9", FALSE, NULL);
 
         QSettings settings("lsyer", "txtreader");
 	QPoint pos = settings.value("pos", QPoint(100, 60)).toPoint();
         QSize size = settings.value("size", QSize(840, 618)).toSize();
 	curFile = settings.value("curFile", QString("")).toString();
         curOffset = -1;
-        txtFont.fromString(settings.value("txtFont",QString("MHeiGB18030C-Medium,18,-1,5,50,0,0,0,0,0")).toString());
+        txtFont.fromString(settings.value("txtFont",QString("MHeiGB18030C-Medium,28,-1,5,50,0,0,0,0,0")).toString());
         txtColor=QColor(settings.value("txtColor", QColor("#000000")).toString());
 	o_isfullscreen = settings.value("o_isfullscreen", 0).toBool();
-	bgColor=QColor(settings.value("bgColor", QColor("#ffffff")).toString());
+	bgColor=QColor(settings.value("bgColor", QColor("#e0d686")).toString());
 	bgImage = settings.value("bgImage", QString("")).toString();
 	codecstr = settings.value("codecstr", QString("GBK")).toString();
         uilang = settings.value("uilang", QString("zh_CN")).toString();
         isLandscape = settings.value("isLandscape", 1).toBool();
+        isNightmode = settings.value("isNightmode", 0).toBool();
 
         if(isLandscape)
             setOrientation(ScreenOrientationLockLandscape);
@@ -61,7 +62,10 @@ TxtReader::TxtReader(QString infile)
                 showFullScreen();
         }else{
                 resize(size);
-//                move(pos);
+        }
+        if(isNightmode){
+            isNightmode=false;
+            setbgnight();
         }
 }
 void TxtReader::setOrientation(ScreenOrientation orientation)
@@ -317,6 +321,10 @@ void TxtReader::createActions()
     setfontcolorAct = new QAction("fcolor", this);
     connect(setfontcolorAct, SIGNAL(triggered()), this, SLOT(setfontcolor()));
 
+    setbgnightAct = new QAction("bgnight", this);
+    setbgnightAct->setCheckable(true);
+    connect(setbgnightAct, SIGNAL(triggered()), this, SLOT(setbgnight()));
+
     setbgcolorAct = new QAction("bgcolor", this);
     connect(setbgcolorAct, SIGNAL(triggered()), this, SLOT(setbgcolor()));
 
@@ -430,6 +438,7 @@ void TxtReader::createTrayIcon()
 
     bgMenu = trayIconMenu->addMenu(tr("bgmenu"));
     bgMenu->addAction(scnAction);
+    bgMenu->addAction(setbgnightAct);
     bgMenu->addAction(setbgcolorAct);
     bgMenu->addAction(setbgimageAct);
     bgMenu->addAction(delbgimageAct);
@@ -465,6 +474,23 @@ void TxtReader::rotate()
     }
 }
 
+void TxtReader::setbgnight()
+{
+    if(isNightmode){
+        isNightmode = false;
+        setbgnightAct->setChecked(false);
+        setStyleSheet( "TxtReader {background-color: "+bgColor.name()+";background-image: url("+bgImage+");background-position:center;}");
+        viewContentEdit->setStyleSheet("color:"+txtColor.name()+";");
+    }else{
+        isNightmode = true;
+        setbgnightAct->setChecked(true);
+        QColor tmpColor;
+        tmpColor=QColor("#111f3b");
+        setStyleSheet( "TxtReader {background-color: "+tmpColor.name()+";background-image: url("+bgImage+");background-position:center;}");
+        tmpColor=QColor("#7d7d7d");
+        viewContentEdit->setStyleSheet("color:"+tmpColor.name()+";");
+    }
+}
 void TxtReader::setScreenLight()
 {
     if(screenblank->isActive()){
@@ -584,10 +610,11 @@ void TxtReader::slotJumpToPage()
     QDialog d;
     d.setWindowTitle(tr("Jump to:"));
     QGridLayout l;
-    QSlider t;
+    QSlider t;//(Qt::Horizontal);
     t.setOrientation(Qt::Horizontal);
     t.setRange(1,TotalPageNum);
     t.setValue(curPageNum);
+    //connect(&t,SIGNAL(valueChanged(value)),&d,SLOT(setWindowTitle(QString::number(value))));
     QPushButton b(tr("&Jump"),this);
     connect(&b,SIGNAL(clicked()),&d,SLOT(accept()));
     l.addWidget(&t);
@@ -765,6 +792,7 @@ void TxtReader::setfontcolor()
 {
 	QColor Color = QColorDialog::getColor(txtColor, this);
 	if (Color.isValid()) {
+                if(isNightmode) setbgnight();
                 txtColor=Color;
                 viewContentEdit->setStyleSheet("color:"+txtColor.name()+";");
 	}
@@ -774,6 +802,7 @@ void TxtReader::setbgcolor()
 {
 	QColor Color = QColorDialog::getColor(bgColor, this);
 	if (Color.isValid()) {
+                if(isNightmode) setbgnight();
 		bgColor=Color;
                 setStyleSheet( "TxtReader {background-color: "+bgColor.name()+";background-image: url("+bgImage+");background-position:center;;}");
 	}
@@ -791,8 +820,11 @@ void TxtReader::setbgimage()
 void TxtReader::resetbg()
 {
     bgImage = "";
-    bgColor=QColor(Qt::white);
-	setStyleSheet( "TxtReader {background-color: "+bgColor.name()+";background-image: url("+bgImage+");background-position:center;}");  	
+    if(isNightmode) setbgnight();
+    bgColor=QColor("#e0d686");
+    setStyleSheet( "TxtReader {background-color: "+bgColor.name()+";background-image: url("+bgImage+");background-position:center;}");
+    txtColor=QColor("#000000");
+    viewContentEdit->setStyleSheet("color:"+txtColor.name()+";");
 }
 void TxtReader::hideAndRestore()
 {
@@ -829,6 +861,7 @@ void TxtReader::retranslateUi()
     setfontAct->setText(tr("&Set Font"));
     setfontcolorAct->setText(tr("&Color"));
     scnAction->setText(tr("&Screen Light"));
+    setbgnightAct->setText(tr("&Night Mode"));
     setbgcolorAct->setText(tr("&Bg color"));
     setbgimageAct->setText(tr("&Bg image"));
     delbgimageAct->setText(tr("&Reset"));
@@ -858,6 +891,7 @@ void TxtReader::quitaction()
 	settings.setValue("codecstr", codecstr);
         settings.setValue("uilang", uilang);
         settings.setValue("isLandscape", isLandscape);
+        settings.setValue("isNightmode", isNightmode);
 
         if(oss) osso_deinitialize(oss);
         saveBookDependSetting();
