@@ -32,7 +32,7 @@ private:
         QColor txtColor,bgColor;
         int curPageNum,curOffset;
 	bool o_isfullscreen;
-        bool isLandscape;
+        bool isLandscape,isNightmode;
 
         ReaderView *viewContentEdit;
         QTimer *showbutton;
@@ -76,6 +76,7 @@ private:
 	QAction *setfontcolorAct;
 	QMenu * bgMenu;
 	QAction * scnAction;
+	QAction * setbgnightAct;
 	QAction * setbgcolorAct;
 	QAction * setbgimageAct;
 	QAction * delbgimageAct;
@@ -124,6 +125,7 @@ private slots:
 	void subTxtSize();
 	void setfont();
 	void setfontcolor();
+	void setbgnight();
 	void setbgcolor();
 	void setbgimage();
         void resetbg();
